# Detect_Mask
### Fast AI required to run this module
### Just Import detect_mask module : import detect_mask
### call the method Determine and pass the path of the photo of the variable : detect_mask.Determine(path)
### Returns a Tuple :
####  (0,'No Mask')
####  (1,'Mask')